/* Generated by re2c 1.0.3 */
#line 3 "Zend/zend_ini_scanner_defs.h"

enum YYCONDTYPE {
	yycINITIAL,
	yycST_OFFSET,
	yycST_SECTION_VALUE,
	yycST_VALUE,
	yycST_SECTION_RAW,
	yycST_DOUBLE_QUOTES,
	yycST_VARNAME,
	yycST_RAW,
};
