#ifndef TSRM_CONFIG_W32_H
#define TSRM_CONFIG_W32_H

#include <../main/config.w32.h>
#include "Zend/zend_config.w32.h"

#define HAVE_UTIME 1
#define HAVE_ALLOCA 1

#include <malloc.h>
#include <stdlib.h>
#include <crtdbg.h>

#endif

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: sw=4 ts=4 fdm=marker
 * vim<600: sw=4 ts=4
 */
